@@ -9,12 +9,18 @@ from importlib.resources import path
 class Translator:
     def __init__(self):
         self.dict_file = path('data.symbols', 'sun_dictionary.csv')
+        print(type(self.dict_file))
+        print(self.dict_file)
         self.font_path = path('data.fonts', 'SUN7_8_1210.ttf')
+        print(type(self.font_path))
+        print(self.font_path)
         self.sun_symbols = self.create_dict()
 
     def create_dict(self):
 
         sun_dict = {}
+        print(type(self.dict_file))
+        print(self.dict_file)
         with open(self.dict_file) as file:
             reader = csv.reader(file)
             for row in reader:
